security: documentation: clarify return values for getKey and getCerticicate.
diff --git a/ndn-cpp/security/identity/identity-storage.hpp b/ndn-cpp/security/identity/identity-storage.hpp
index 0e22432..db6ab0e 100644
--- a/ndn-cpp/security/identity/identity-storage.hpp
+++ b/ndn-cpp/security/identity/identity-storage.hpp
@@ -88,6 +88,7 @@
   /**
    * Get the public key DER blob from the identity storage.
    * @param keyName The name of the requested public key.
+   * @return The DER Blob.  If not found, return a Blob with a null pointer.
    */
   virtual Blob
   getKey(const Name& keyName) = 0;
@@ -125,7 +126,7 @@
    * Get a certificate from the identity storage.
    * @param certificateName The name of the requested certificate.
    * @param allowAny If false, only a valid certificate will be returned, otherwise validity is disregarded.
-   * @return The requested certificate.
+   * @return The requested certificate.  If not found, return a shared_ptr with a null pointer.
    */
   virtual ptr_lib::shared_ptr<Certificate> 
   getCertificate(const Name &certificateName, bool allowAny = false) = 0;
@@ -180,10 +181,10 @@
   /**
    * Set the default key name for the specified identity.
    * @param keyName The key name.
    * @param identityName (optional) The identity name to check the keyName.
    */
   virtual void 
-  setDefaultKeyNameForIdentity(const Name& keyName, const Name& identityName = Name()) = 0;
+  setDefaultKeyNameForIdentity(const Name& keyName, const Name& identityNameCheck = Name()) = 0;
 
   /**
    * Set the default key name for the specified identity.
@@ -180,10 +181,10 @@
    * Set the default key name for the specified identity.
    * @param keyName The key name.
-   * @param identityName (optional) The identity name to check the keyName.
+   * @param identityNameCheck (optional) The identity name to check the keyName.
    */
   virtual void 